diff --git a/core/misc/active-link.js b/core/misc/active-link.js
index d6bd9e4095ca1794a176e33214baa91d4fb2f9c3..e3ca0e239a9abdd40816b1a0f2df96fc88771110 100644
--- a/core/misc/active-link.js
+++ b/core/misc/active-link.js
@@ -55,6 +55,7 @@
       const il = activeLinks.length;
       for (let i = 0; i < il; i++) {
         activeLinks[i].classList.add('is-active');
+        activeLinks[i].setAttribute('aria-current', 'page');
       }
     },
     detach(context, settings, trigger) {
@@ -65,6 +66,7 @@
         const il = activeLinks.length;
         for (let i = 0; i < il; i++) {
           activeLinks[i].classList.remove('is-active');
+          activeLinks[i].removeAttribute('aria-current');
         }
       }
     },
diff --git a/core/tests/Drupal/Tests/Core/EventSubscriber/ActiveLinkResponseFilterTest.php b/core/tests/Drupal/Tests/Core/EventSubscriber/ActiveLinkResponseFilterTest.php
index 472078f36ccf9938919c4455082aabbed1b8e19f..fecf8786d43223131e0a235b93a5fbc595d0a7fd 100644
--- a/core/tests/Drupal/Tests/Core/EventSubscriber/ActiveLinkResponseFilterTest.php
+++ b/core/tests/Drupal/Tests/Core/EventSubscriber/ActiveLinkResponseFilterTest.php
@@ -91,8 +91,8 @@ public function providerTestSetLinkActiveClass() {
     $attributes = [
       'data-drupal-link-system-path' => 'my-front-page',
     ];
-    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes];
-    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['hreflang' => 'en']];
+    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['aria-current' => 'page']];
+    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['hreflang' => 'en', 'aria-current' => 'page']];
     // Matching path, plus all non-matching variations.
     $situations[] = ['context' => $context, 'is active' => FALSE, 'attributes' => $attributes + ['hreflang' => 'nl']];
     $situations[] = ['context' => $context, 'is active' => FALSE, 'attributes' => $attributes + ['data-drupal-link-query' => '{"foo":"bar"}']];
@@ -105,8 +105,8 @@ public function providerTestSetLinkActiveClass() {
     $attributes = [
       'data-drupal-link-system-path' => '<front>',
     ];
-    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes];
-    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['hreflang' => 'en']];
+    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['aria-current' => 'page']];
+    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['hreflang' => 'en', 'aria-current' => 'page']];
     // Special matching path, plus all non-matching variations.
     $situations[] = ['context' => $context, 'is active' => FALSE, 'attributes' => $attributes + ['hreflang' => 'nl']];
     $situations[] = ['context' => $context, 'is active' => FALSE, 'attributes' => $attributes + ['data-drupal-link-query' => '{"foo":"bar"}']];
@@ -128,8 +128,8 @@ public function providerTestSetLinkActiveClass() {
     $attributes = [
       'data-drupal-link-system-path' => 'llama',
     ];
-    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes];
-    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['hreflang' => 'nl']];
+    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['aria-current' => 'page']];
+    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['hreflang' => 'nl', 'aria-current' => 'page']];
     // Matching path, plus all non-matching variations.
     $situations[] = ['context' => $context, 'is active' => FALSE, 'attributes' => $attributes + ['hreflang' => 'en']];
     $situations[] = ['context' => $context, 'is active' => FALSE, 'attributes' => $attributes + ['data-drupal-link-query' => '{"foo":"bar"}']];
@@ -163,8 +163,8 @@ public function providerTestSetLinkActiveClass() {
     $attributes = [
       'data-drupal-link-system-path' => 'llama',
     ];
-    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['data-drupal-link-query' => Json::encode(['foo' => 'bar'])]];
-    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['hreflang' => 'nl', 'data-drupal-link-query' => Json::encode(['foo' => 'bar'])]];
+    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['aria-current' => 'page', 'data-drupal-link-query' => Json::encode(['foo' => 'bar'])]];
+    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['hreflang' => 'nl', 'aria-current' => 'page', 'data-drupal-link-query' => Json::encode(['foo' => 'bar'])]];
     // Matching path, plus all non-matching variations.
     $situations[] = ['context' => $context, 'is active' => FALSE, 'attributes' => $attributes + ['hreflang' => 'en', 'data-drupal-link-query' => Json::encode(['foo' => 'bar'])]];
     $situations[] = ['context' => $context, 'is active' => FALSE, 'attributes' => $attributes + ['hreflang' => 'nl', 'data-drupal-link-query' => ""]];
@@ -191,8 +191,8 @@ public function providerTestSetLinkActiveClass() {
     $attributes = [
       'data-drupal-link-system-path' => 'llama',
     ];
-    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['data-drupal-link-query' => Json::encode(['foo' => 'bar'])]];
-    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['hreflang' => 'nl', 'data-drupal-link-query' => Json::encode(['foo' => 'bar'])]];
+    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['aria-current' => 'page', 'data-drupal-link-query' => Json::encode(['foo' => 'bar'])]];
+    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['hreflang' => 'nl', 'aria-current' => 'page', 'data-drupal-link-query' => Json::encode(['foo' => 'bar'])]];
     // Matching path, plus all non-matching variations.
     $situations[] = ['context' => $context, 'is active' => FALSE, 'attributes' => $attributes + ['hreflang' => 'en', 'data-drupal-link-query' => Json::encode(['foo' => 'bar'])]];
     $situations[] = ['context' => $context, 'is active' => FALSE, 'attributes' => $attributes + ['data-drupal-link-query' => ""]];
@@ -223,8 +223,8 @@ public function providerTestSetLinkActiveClass() {
     $attributes = [
       'data-drupal-link-system-path' => 'my-front-page',
     ];
-    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['data-drupal-link-query' => Json::encode(['foo' => 'bar'])]];
-    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['hreflang' => 'en', 'data-drupal-link-query' => Json::encode(['foo' => 'bar'])]];
+    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['aria-current' => 'page', 'data-drupal-link-query' => Json::encode(['foo' => 'bar'])]];
+    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['hreflang' => 'en', 'aria-current' => 'page', 'data-drupal-link-query' => Json::encode(['foo' => 'bar'])]];
     // Matching path, plus all non-matching variations.
     $situations[] = ['context' => $context, 'is active' => FALSE, 'attributes' => $attributes + ['hreflang' => 'nl', 'data-drupal-link-query' => Json::encode(['foo' => 'bar'])]];
     $situations[] = ['context' => $context, 'is active' => FALSE, 'attributes' => $attributes + ['data-drupal-link-query' => ""]];
@@ -235,8 +235,8 @@ public function providerTestSetLinkActiveClass() {
     $attributes = [
       'data-drupal-link-system-path' => '<front>',
     ];
-    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['data-drupal-link-query' => Json::encode(['foo' => 'bar'])]];
-    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['hreflang' => 'en', 'data-drupal-link-query' => Json::encode(['foo' => 'bar'])]];
+    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['aria-current' => 'page', 'data-drupal-link-query' => Json::encode(['foo' => 'bar'])]];
+    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['hreflang' => 'en', 'aria-current' => 'page', 'data-drupal-link-query' => Json::encode(['foo' => 'bar'])]];
     // Special matching path, plus all non-matching variations.
     $situations[] = ['context' => $context, 'is active' => FALSE, 'attributes' => $attributes + ['hreflang' => 'nl', 'data-drupal-link-query' => Json::encode(['foo' => 'bar'])]];
     $situations[] = ['context' => $context, 'is active' => FALSE, 'attributes' => $attributes + ['data-drupal-link-query' => ""]];
@@ -255,7 +255,7 @@ public function providerTestSetLinkActiveClass() {
       'data-drupal-link-system-path' => 'my-front-page',
       'data-drupal-link-query' => Json::encode(['baz' => 'qux', 'foo' => 'bar']),
     ];
-    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes];
+    $situations[] = ['context' => $context, 'is active' => TRUE, 'attributes' => $attributes + ['aria-current' => 'page']];
 
     // Loop over the surrounding HTML variations.
     $data = [];
@@ -311,7 +311,7 @@ public function providerTestSetLinkActiveClass() {
       2 => TRUE,
       3 => 'en',
       4 => [],
-      5 => '<a data-drupal-link-system-path="&lt;front&gt;" class="is-active">Once</a> <a data-drupal-link-system-path="&lt;front&gt;" class="is-active">Twice</a>',
+      5 => '<a data-drupal-link-system-path="&lt;front&gt;" class="is-active" aria-current="page">Once</a> <a data-drupal-link-system-path="&lt;front&gt;" class="is-active" aria-current="page">Twice</a>',
     ];
 
     // Test cases to verify that the 'is-active' class is added when on the
@@ -320,9 +320,9 @@ public function providerTestSetLinkActiveClass() {
     // - the matching path (the resolved front page path)
     // - the special matching path ('<front>')
     $front_special_link = '<a data-drupal-link-system-path="&lt;front&gt;">Front</a>';
-    $front_special_link_active = '<a data-drupal-link-system-path="&lt;front&gt;" class="is-active">Front</a>';
+    $front_special_link_active = '<a data-drupal-link-system-path="&lt;front&gt;" class="is-active" aria-current="page">Front</a>';
     $front_path_link = '<a data-drupal-link-system-path="my-front-page">Front Path</a>';
-    $front_path_link_active = '<a data-drupal-link-system-path="my-front-page" class="is-active">Front Path</a>';
+    $front_path_link_active = '<a data-drupal-link-system-path="my-front-page" class="is-active" aria-current="page">Front Path</a>';
     $data[] = [
       0 => $front_path_link . ' ' . $front_special_link,
       1 => 'my-front-page',
@@ -343,7 +343,7 @@ public function providerTestSetLinkActiveClass() {
     // Test cases to verify that links to the front page do not get the
     // 'is-active' class when not on the front page.
     $other_link = '<a data-drupal-link-system-path="other-page">Other page</a>';
-    $other_link_active = '<a data-drupal-link-system-path="other-page" class="is-active">Other page</a>';
+    $other_link_active = '<a data-drupal-link-system-path="other-page" class="is-active" aria-current="page">Other page</a>';
     $data['<front>-and-other-link-on-other-path'] = [
       0 => $front_special_link . ' ' . $other_link,
       1 => 'other-page',
diff --git a/core/lib/Drupal/Core/EventSubscriber/ActiveLinkResponseFilter.php b/core/lib/Drupal/Core/EventSubscriber/ActiveLinkResponseFilter.php
index f160c9d9c378e95c51e9f267338d2922603cb321..8069822daaf2e05d6aa961d1b6888db6f3316427 100644
--- a/core/lib/Drupal/Core/EventSubscriber/ActiveLinkResponseFilter.php
+++ b/core/lib/Drupal/Core/EventSubscriber/ActiveLinkResponseFilter.php
@@ -14,7 +14,9 @@
 
 // cspell:ignore noemptytag
 /**
  * Subscribes to filter HTML responses, to set the 'is-active' class on links.
  *
  * Only for anonymous users; for authenticated users, the active-link asset
  * library is loaded.
@@ -107,7 +109,7 @@ public function onResponse(ResponseEvent $event) {
   }
 
   /**
    * Sets the "is-active" class on relevant links.
    *
    * This is a PHP implementation of the drupal.active-link JavaScript library.
    *
@@ -216,13 +218,14 @@ public static function setLinkActiveClass($html_markup, $current_path, $is_front
       }
 
       // Only if the path, the language and the query match, we set the
-      // "is-active" class.
+      // "is-active" class and add aria-current="page".
       if ($add_active) {
         if (strlen($class) > 0) {
           $class .= ' ';
         }
         $class .= 'is-active';
         $node->setAttribute('class', $class);
+        $node->setAttribute('aria-current', 'page');
 
         // Get the updated tag.
         $updated_tag = $dom->saveXML($node, LIBXML_NOEMPTYTAG);
@@ -14,7 +14,9 @@
 // cspell:ignore noemptytag
 /**
- * Subscribes to filter HTML responses, to set the 'is-active' class on links.
+ * Subscribes to filter HTML responses, to set attributes on active links.
+ *
+ * Sets the 'is-active' class and sets the aria-current attribute to 'page'.
  *
  * Only for anonymous users; for authenticated users, the active-link asset
@@ -107,7 +109,7 @@ public function onResponse(ResponseEvent $event) {
 
   /**
-   * Sets the "is-active" class on relevant links.
+   * Sets the "is-active" class and aria-current attribute on relevant links.
    *
    * This is a PHP implementation of the drupal.active-link JavaScript library.